@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from benedict.dicts import benedict
+from benedict.dicts import benedict, benediction
 from benedict.metadata import (
     __author__, __copyright__, __description__,
     __license__, __title__, __version__,
 )
-
